@@ -64,8 +64,15 @@ sub field_names {
 }
 
 sub value_for {
-    my @values = shift->values_for( shift );
-    return $values[ 0 ];
+    my ( $self, $key ) = @_;
+
+    for my $field ( $self->fields ) {
+        if ( $field->name eq $key ) {
+            return $field->value;
+        }
+    }
+
+    return;
 }
 
 sub values_for {
@@ -165,10 +172,10 @@ Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2012 National Adult Literacy Database
+Copyright 2008-2013 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
